#!/usr/bin/env node
import { EsouiPublish } from './index';

import yargs from 'yargs';
const argv = yargs.options({
  token: { type: 'string', description: "Recommend setting `ESOUI_TOKEN` environment variable to avoid exposing token via logs. Otherwise this parameter is required." },
  id: { type: 'number', demandOption: true, description: "ID of the addon to update" },
  version: { type: 'string', description: "Version of the new version" },
  description: { type: 'string', description: "Name of the file that contains the addon description. (aka what is shown on the main page of your addon)" },
  changelog: { type: 'string', description: "Name of the file that contains the changelog" },
  compatibility: { type: 'string', description: "Game version your addon supports. (i.e. `5.2.5`)" },
  updatefile: { type: 'string', description: "Name of the file that contains the zip package to upload to esoui" },
  testDeploy: { type: 'boolean', description: "Set to true to validate upload parameters without updating the actual add on" }
}).argv;

const token = argv.token || process.env.ESOUI_TOKEN;
if (token) {
  EsouiPublish.publish(token, argv.id, argv.version, argv.description, argv.changelog, argv.compatibility, argv.updatefile, argv.testDeploy)
    .then(response => console.log(JSON.stringify(response, null, 2)))
    .catch(console.error);
} else {
  throw new Error('No token found. Either provide via `--token=<you\'re token>` or set the ESOUI_TOKEN environment variable');
}
